" Vim keymap file for Turkish F layout
" Maintainer: Emir SARI <bitigchi@me.com>
" Last changed: 5 August 2020

scriptencoding utf-8
let b:keymap_name = "tr-f"
loadkeymap

F A LATIN CAPITAL LETTER A
< B LATIN CAPITAL LETTER B
V C LATIN CAPITAL LETTER C
B Ç LATIN CAPITAL LETTER C WITH CEDILLA
Y D LATIN CAPITAL LETTER D
D E LATIN CAPITAL LETTER E
Q F LATIN CAPITAL LETTER F
W G LATIN CAPITAL LETTER G
E Ğ LATIN CAPITAL LETTER G WITH BREVE
O H LATIN CAPITAL LETTER H
R I LATIN CAPITAL LETTER I
S İ LATIN CAPITAL LETTER I WITH DOT ABOVE
Z J LATIN CAPITAL LETTER J
J K LATIN CAPITAL LETTER K
K M LATIN CAPITAL LETTER M
I N LATIN CAPITAL LETTER N
T O LATIN CAPITAL LETTER O
X Ö LATIN CAPITAL LETTER O WITH DIAERESIS
U R LATIN CAPITAL LETTER R
M S LATIN CAPITAL LETTER S
\" Ş LATIN CAPITAL LETTER S WITH CEDILLA
H T LATIN CAPITAL LETTER T
A U LATIN CAPITAL LETTER U
G Ü LATIN CAPITAL LETTER U WITH DIAERESIS
C V LATIN CAPITAL LETTER V
: Y LATIN CAPITAL LETTER Y
N Z LATIN CAPITAL LETTER Z

{ Q LATIN CAPITAL LETTER Q
} W LATIN CAPITAL LETTER W
| X LATIN CAPITAL LETTER X

± * ASTERISK
@ " QUOTATION MARK
# ^ CIRCUMFLEX ACCENT
^ & AMPERSAND
& ' APOSTROPHE
* ( LEFT PARENTHESIS
( ) RIGHT PARENTHESIS
) = EQUALS SIGN
_ ? QUESTION MARK
+ _ LOW LINE
> : COLON
? ; SEMICOLON
~ > GREATER-THAN SIGN

Å Û LATIN CAPITAL LETTER U WITH CIRCUMFLEX
Í Î LATIN CAPITAL LETTER I WITH CIRCUMFLEX
Ï Â LATIN CAPITAL LETTER A WITH CIRCUMFLEX

f a LATIN SMALL LETTER A
, b LATIN SMALL LETTER B
v c LATIN SMALL LETTER C
b ç LATIN SMALL LETTER C WITH CEDILLA
y d LATIN SMALL LETTER D
d e LATIN SMALL LETTER E
q f LATIN SMALL LETTER F
w g LATIN SMALL LETTER G
e ğ LATIN SMALL LETTER G WITH BREVE
o h LATIN SMALL LETTER H
r ı LATIN SMALL LETTER I
s i LATIN SMALL LETTER I WITH DOT ABOVE
z j LATIN SMALL LETTER J
j k LATIN SMALL LETTER K
k m LATIN SMALL LETTER M
i n LATIN SMALL LETTER N
t o LATIN SMALL LETTER O
x ö LATIN SMALL LETTER O WITH DIAERESIS
u r LATIN SMALL LETTER R
m s LATIN SMALL LETTER S
\' ş LATIN SMALL LETTER S WITH CEDILLA
h t LATIN SMALL LETTER T
a u LATIN SMALL LETTER U
g ü LATIN SMALL LETTER U WITH DIAERESIS
c v LATIN SMALL LETTER V
; y LATIN SMALL LETTER Y
n z LATIN SMALL LETTER Z

[ q LATIN SMALL LETTER Q
] w LATIN SMALL LETTER W
\\ x LATIN SMALL LETTER X

§ + PLUS SIGN
- / SOLIDUS
= - HYPHEN-MINUS
/ , COMMA
` < LESS-THAN SIGN

£ # NUMBER SIGN
¶ { LEFT CURLY BRACKET
• [ LEFT SQUARE BRACKET
ª ] RIGHT SQUARE BRACKET
º } RIGHT CURLY BRACKET
– \\ REVERSE SOLIDUS
≠ | VERTICAL LINE
œ @ COMMERCIAL AT
‘ ~ TILDE
å û LATIN SMALL LETTER U WITH CIRCUMFLEX
ß î LATIN SMALL LETTER I WITH CIRCUMFLEX
∂ € EURO SIGN
ƒ â LATIN SMALL LETTER A WITH CIRCUMFLEX
˙ ₺ TURKISH LIRA SIGN
¬ £ POUND SIGN
… ¥ YEN SIGN
« ` GRAVE ACCENT
